update path names to match new svn structure
authorlaca
Wed, 28 Feb 2007 23:28:48 +0000
changeset 9401 72746c79ffd2
parent 9400 f3c0f4f1c2ee
child 9402 41fbd8edcb94
update path names to match new svn structure
.pkgtoolrc
cron-nightly.sh
cron-script.sh
nightly-beijing.env
nightly-ireland.env
scripts/check_unused.sh
scripts/l10n_getname.pl
scripts/reorder-patches
--- a/.pkgtoolrc	Wed Feb 28 23:26:59 2007 +0000
+++ b/.pkgtoolrc	Wed Feb 28 23:28:48 2007 +0000
@@ -1,14 +1,14 @@
 # tarballdirs [string]: colon (:) separated list of directories where source tarballs are searched for
-tarballdirs:	/sgnome/tarballs/gnome2.18:/sgnome/tarballs/gnome2.15:/sgnome/tarballs/gnome2.14:/sgnome/tarballs/moz-evo:/jds/packages/SOURCES:${MYDIR}/manpages/sun-manpage-tarballs:${MYDIR}/../po-sun/po-sun-tarballs:${tarballdirs}
+tarballdirs:	/sgnome/tarballs/gnome2.18:/sgnome/tarballs/gnome2.15:/sgnome/tarballs/gnome2.14:/sgnome/tarballs/moz-evo:/jds/packages/SOURCES:${MYDIR}/manpages/sun-manpage-tarballs:${MYDIR}/po-sun/po-sun-tarballs:${tarballdirs}
 
 # logdir [string]: the directory for saving log files
 # logdir:	/tmp
 
 # patchdirs [string]: colon (:) separated list of directories where source patches are searched for
-patchdirs:	${MYDIR}/../patches:${MYDIR}/patches
+patchdirs:	${MYDIR}/patches
 
 # specdirs [string]: colon (:) separated list of directories where spec files are searched for
-specdirs:	${MYDIR}:${MYDIR}/..:${MYDIR}/extra-specs
+specdirs:	${MYDIR}:${MYDIR}/include:${MYDIR}/base-specs
 
 # sourcedirs [string]: colon (:) separated list of directories where extra sources (not tarballs) are searched for
-sourcedirs:	${MYDIR}/../ext-sources:${MYDIR}/manpages/entities:${MYDIR}/manpages/sman1:${MYDIR}/manpages/sman1m:${MYDIR}/manpages/sman3:${MYDIR}/manpages/sman3tiff:${MYDIR}/manpages/sman4:${MYDIR}/manpages/sman5:${MYDIR}/../manpages/man1:${MYDIR}/../manpages/man3:${MYDIR}/../manpages/man4:${MYDIR}/../manpages/man5
+sourcedirs:	${MYDIR}/ext-sources
--- a/cron-nightly.sh	Wed Feb 28 23:26:59 2007 +0000
+++ b/cron-nightly.sh	Wed Feb 28 23:28:48 2007 +0000
@@ -143,7 +143,7 @@
    pkgtool uninstall-pkgs --with-l10n --with-tjds $thisSpec >/dev/null
    # remove-gnome will now remove anything left from uninstall-pkgs in case
    # of a packaging change for example
-   $SPECDIR/remove-gnome --version jds -q -f --no_extras > /dev/null 2>&1
+   $SPECDIR/scripts/remove-gnome --version jds -q -f --no_extras > /dev/null 2>&1
 }
 
 do_clean_pkgs() {
@@ -196,7 +196,7 @@
 choose_build() {
    if [ "x$thisSpec" = "x" ]; then
       # no spec file was chosen, build everything
-      thisSpec='*.spec'; export thisSpec
+      thisSpec='*.spec closed/*.spec'; export thisSpec
       echo "-- building following components: $thisSpec"
    else
       # verify chosen spec file
--- a/cron-script.sh	Wed Feb 28 23:26:59 2007 +0000
+++ b/cron-script.sh	Wed Feb 28 23:28:48 2007 +0000
@@ -2,11 +2,11 @@
 
 # Sample usage in crontab:
 # Run, Mon-Fri at 1:30am. Add to build user's crontab.
-#   30 1 * * 1-5 . /jds/cbe/bin/env.sh; cd /jds/spec-files/Solaris; I_KNOW_WHAT_IM_DOING=yes ./cron-script.sh
+#   30 1 * * 1-5 . /jds/cbe/bin/env.sh; cd /jds/spec-files; I_KNOW_WHAT_IM_DOING=yes ./cron-script.sh
 #
 # The same with a jail. Add to root's crontab. Example assumes 'gbuild' is the
 # build user
-#   30 1 * * 1-5 /usr/sbin/chroot /path/to/jail/root /usr/bin/su - gbuild -c ". /jds/cbe/bin/env.sh; cd /jds/spec-files/Solaris; I_KNOW_WHAT_IM_DOING=yes ./cron-script.sh"
+#   30 1 * * 1-5 /usr/sbin/chroot /path/to/jail/root /usr/bin/su - gbuild -c ". /jds/cbe/bin/env.sh; cd /jds/spec-files; I_KNOW_WHAT_IM_DOING=yes ./cron-script.sh"
 #
 # $Id$
 
@@ -104,12 +104,9 @@
 
 cd $SPECDIR || fatal_error "$SPECDIR not found"
 
-cd ..
-
 #revert any local changes
 svn revert -R .
 
-#cvs -q up -Pd > /dev/null 2>&1 || fatal_error "CVS update failed"
 # checkout-out SVN copy *MUST* be read-only, or "update" needs passwd
 svn -q up > /dev/null 2>&1 || fatal_error "SVN update failed"
 cd $SPECDIR
@@ -121,12 +118,12 @@
 pkgtool uninstall-pkgs --with-l10n --with-tjds *.spec >/dev/null
 # remove-gnome will now remove anything left from uninstall-pkgs in case
 # or a packaging change for example
-./remove-gnome --version jds -q -f --no_extras > /dev/null 2>&1
+$SPECDIR/scripts/remove-gnome --version jds -q -f --no_extras > /dev/null 2>&1
 
 rm -rf /jds/packages/PKGS/*
 rm -rf /jds/packages/SPKGS/*
 rm -rf /jds/packages/BUILD/*
-rm -rf /var/tmp/*-build
+rm -rf /var/tmp/pkgbuild-*/*
 
 # if the log directory exists, open a new one with numbered suffix
 NEW_LOGDIR=$LOGDIR
@@ -145,13 +142,13 @@
 # Rebuild the manpage tarballs
 cd $SPECDIR/manpages
 make
-cd $SPECDIR/../po-sun
+cd $SPECDIR/po-sun
 make clean
 make
 cd $SPECDIR
 
 # start the build
-pkgtool -v --nightly --date "$RELEASE_DATE" build *.spec \
+pkgtool -v --nightly --date "$RELEASE_DATE" build *.spec closed/*.spec \
         --logdir=$WEBROOT/$LOGDIR \
         --logdir-url=http://gnome.ireland/$LOGDIR \
 	[email protected] \
@@ -195,7 +192,7 @@
 grep 'is an absolute symlink' $WEBROOT/$LOGDIR/*.log >>/tmp/build.log.$$
 
 # Count the number of local patches.
-patch_count=`ls $SPECDIR/../patches/*.diff | wc -l`
+patch_count=`ls $SPECDIR/patches/*.diff | wc -l`
 echo "PATCH COUNT: $patch_count local patches used in this build.">>/tmp/build.log.$$
 
 # send warnings, errors and summary in email
--- a/nightly-beijing.env	Wed Feb 28 23:26:59 2007 +0000
+++ b/nightly-beijing.env	Wed Feb 28 23:28:48 2007 +0000
@@ -23,9 +23,9 @@
 
 # other vars
 TEMP_DIR=/export/home/mrbld/temp
-SPECDIR=$TEMP_DIR/trunk/Solaris
+SPECDIR=$TEMP_DIR/trunk
 BUILD_BASE=/jds/packages
-PRODNAME="G2.14"
+PRODNAME="G2.18"
 
 # directory to copy rpms/srpms to on the remote host
 RPMSDIR="/export/storage/download/opensolaris/new_nightly/S${OSrel}${OSarch}"
@@ -39,7 +39,7 @@
 LOGDIR_BASE_URL="http://sceri.prc.sun.com/nightly/new_nightly/web"
 
 # tarballsdir
-TARBALLSDIR="/net/decathlon.prc/export/storage/tarballs-from-ireland/gnome2.14"
+TARBALLSDIR="/net/decathlon.prc/export/storage/tarballs-from-ireland/gnome2.18"
 
 # subdir to keep logs and reports on the webserver
 WEBDIR="logs/nightly/S${OSrel}${OSarch}"
--- a/nightly-ireland.env	Wed Feb 28 23:26:59 2007 +0000
+++ b/nightly-ireland.env	Wed Feb 28 23:28:48 2007 +0000
@@ -23,12 +23,12 @@
 
 # other vars
 TEMP_DIR=/export/home/gbuild/temp
-SPECDIR=$TEMP_DIR/trunk/Solaris
+SPECDIR=$TEMP_DIR/trunk
 BUILD_BASE=/jds/packages
-PRODNAME="G2.14"
+PRODNAME="G2.18"
 
 # directory to copy rpms/srpms to on the remote host
-RPMSDIR="/sgnome/pkgs/gnome2.14/S${OSrel}${OSarch}/nightly"
+RPMSDIR="/sgnome/pkgs/gnome2.18/S${OSrel}${OSarch}/nightly"
 
 # reply-to/to address to send the build log as/to
 EMAIL_ERRORS_TO="[email protected]"
@@ -39,7 +39,7 @@
 LOGDIR_BASE_URL="http://gnome.ireland.sun.com"
 
 # tarballsdir
-TARBALLSDIR="/net/decathlon.prc/export/home/storage/tarballs-from-ireland/gnome2.14"
+TARBALLSDIR="/sgnome/tarballs/gnome2.18"
 
 # subdir to keep logs and reports on the webserver
-WEBDIR="gnome/releng/jds/gnome2.14/nightly/S${OSrel}${OSarch}"
+WEBDIR="gnome/releng/jds/gnome2.18/nightly/S${OSrel}${OSarch}"
--- a/scripts/l10n_getname.pl	Wed Feb 28 23:26:59 2007 +0000
+++ b/scripts/l10n_getname.pl	Wed Feb 28 23:28:48 2007 +0000
@@ -90,7 +90,7 @@
     }
 
     if ($os eq "linux") {
-      $opt_specdir = "/jds/packages/spec-files/Solaris";
+      $opt_specdir = "/jds/packages/spec-files/base-specs";
     } else {
       $opt_specdir = "/jds/packages/spec-files";
     }
--- a/scripts/reorder-patches	Wed Feb 28 23:26:59 2007 +0000
+++ b/scripts/reorder-patches	Wed Feb 28 23:28:48 2007 +0000
@@ -14,8 +14,8 @@
 
 rename () {
     svn rename $1 $2
-    if [ -f ../$3.spec ]; then
-	perl -pi -e "s/Patch(.*):(\s*)$1/Patch\$1:\$2$2/" ../$3.spec
+    if [ -f ../base-specs/$3.spec ]; then
+	perl -pi -e "s/Patch(.*):(\s*)$1/Patch\$1:\$2$2/" ../base-specs/$3.spec
     else
 	echo "WARNING: $3.spec not found"
     fi
--- a/scripts/check_unused.sh	Wed Feb 28 23:26:59 2007 +0000
+++ b/scripts/check_unused.sh	Wed Feb 28 23:28:48 2007 +0000
@@ -30,7 +30,7 @@
 
 # Go to the spec-files directory and ensure other dirs present.
 cd $ScriptDir/..
-if [ ! -d patches -o ! -d Solaris -o ! -d Solaris/patches -o ! -d Solaris/extra-specs -o ! -d ext-sources ]
+if [ ! -d patches -o ! -d base-specs -o ! -d closed -o ! -d ext-sources ]
 then
   echo "ERROR: Expected directory structure not present. Contact [email protected]."
   exit 1
@@ -38,13 +38,13 @@
 
 
 case "$1" in
   # Search for '^Patch.*' in Linux, Solaris and extra-specs spec files.
   -patches|-p*)
-      for d in patches Solaris/patches
+      for d in patches
       do
         for f in `cd $d; ls *.diff`
         do
-          found=`grep "^Patch.*$f" *.spec Solaris/*.spec Solaris/extra-specs/*.spec`
+          found=`grep "^Patch.*$f" *.spec base-specs/*.spec closed/*.spec`
           if [ -z "$found" ]
           then
             echo $d/$f
@@ -59,13 +59,13 @@
       do
         if [ -f ext-sources/$f ]
         then
-          found=`grep "^Source.*$f" *.spec Solaris/*.spec Solaris/extra-specs/*.spec`
+          found=`grep "^Source.*$f" *.spec base-specs/*.spec closed/*.spec`
           if [ -z "$found" ]
           then
-            found=`grep "^SUNW_Copyright.*$f" Solaris/*.spec`
+            found=`grep "^SUNW_Copyright.*$f" *.spec closed/*.spec`
             if [ -z "$found" ]
             then
-              found=`grep "^%.class.*$f" Solaris/*.spec`
+              found=`grep "^%.class.*$f" *.spec closed/*.spec`
               if [ -z "$found" ]
               then
                 echo $f
@@ -79,7 +79,7 @@
   -linux-only|-l*)
       for f in *.spec
       do
-        found=`grep "^%use.*$f" Solaris/*.spec`
+        found=`grep "^%use.*$f" *.spec closed/*.spec`
         if [ -z "$found" ]
         then
           echo $f
@@ -38,13 +38,13 @@
 
 case "$1" in
-  # Search for '^Patch.*' in Linux, Solaris and extra-specs spec files.
+  # Search for '^Patch.*' in Solaris, base and closed spec files.
   -patches|-p*)